SystemOrganization addCategory: #'Xpf-CodeMarker'!
SystemOrganization addCategory: #'Xpf-CodeMarker-Commands'!
SystemOrganization addCategory: #'Xpf-Tests-Models'!
SystemOrganization addCategory: #'Xpf-Models'!
SystemOrganization addCategory: #Xpf!

!OBCmdMultiView methodsFor: '*xpf-codemarker' stamp: 'mt 2/13/2009 14:27'!
execute
	|viewType|
	viewType := OBChoiceRequest labels: #(Source Bytecode Decompile PrettyPrint Xpf).
	self styler: SHTextStylerST80 new.
	viewType ifNotNil: [self perform: (#toggle, viewType) asSymbol]! !

!OBCmdMultiView methodsFor: '*xpf-codemarker' stamp: 'cs 1/15/2009 17:24'!
styler: styler
	| panel morph |
	
	panel := requestor browser panels 
		detect: [ :each | each isKindOf: OBDefinitionPanel ]
		ifNone: [ ^ self ].
	morph := OBPluggableTextMorph allSubInstances
		detect: [ :each | each model == panel ]
		ifNone: [ ^ self ].
	morph styler: (styler
		view: morph;
		yourself).! !

!OBCmdMultiView methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:47'!
toggleXpf

	self styler: XpfTextStyler new.
	self setTextInDefinitionPanel: target source.! !

!String methodsFor: '*xpf-codemarker' stamp: 'topa 2/12/2009 21:34'!
findAllStrings: aString
	"Returns a collection with all starting indices of the given string in me."
	
	|indices currentStartIndex|
	indices := Bag new.
	currentStartIndex := 1.
	
	[currentStartIndex := (self findString: aString startingAt: currentStartIndex) + 1.
		currentStartIndex > 1 
	] whileTrue: [indices add: currentStartIndex - 1].

	^indices! !

TestCase subclass: #XpfTestCase
	instanceVariableNames: 'originalDatabase'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Models'!

XpfTestCase subclass: #XpfProjectTest
	instanceVariableNames: 'testProject testUser projects users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Models'!

!XpfProjectTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:27'!
setUp
	projects := XpfProject projects. XpfProject projects: Set new.
	users := XpfUser users. XpfUser users: Set new.
	testProject := XpfProject new title: 'testProject'.
	testUser := 	XpfUser new
			login: 'christopher.schuster';
			firstName: 'Christopher';
			lastName: 'Schuster';
			email: 'christopher.schuster@student.hpi.uni-potsdam.de'.! !

!XpfProjectTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:27'!
tearDown
	XpfProject projects: projects.
	XpfUser users: users.
	testProject := nil.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 2/13/2009 16:06'!
testAttributes
	| user |
	user := XpfProject new.
	self
		checkAccessor: #title on: user with: 'xpforums'.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'topa 2/16/2009 17:25'!
testHasDevelopers
	
	| developerCount userCount developer|
	
	developerCount := testProject developers size.
	userCount := XpfUser all size.
	developer := testProject attachDeveloper: testUser.
		
	self 
		should: XpfUser all size = (userCount + 1);
		should: testProject developers size = (developerCount + 1);
		should: (XpfUser all includes: developer);
		should: (testProject developers includes: developer).
	testProject detachDeveloper: developer.
	
	self 
		should: XpfUser all size = (userCount + 1);
		should: testProject developers size = developerCount;
		should: (XpfUser all includes: developer);
		shouldnt: (testProject developers includes: developer).! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:29'!
testNewAndDelete
	| project oldCount |
	
	oldCount := XpfProject all size.
	
	project := XpfProject addProject:
		(XpfProject new
			title: 'xpforums';
			yourself).
		
	self 
		should: XpfProject all size = (oldCount + 1) description: 'Project count is not valid for database.';
		should: (XpfProject all anySatisfy: [ :each | each title = 'xpforums' ]).
	
	XpfProject deleteProject: project.
	
	self should: XpfProject all size = oldCount description: 'Project count is not valid for database after deletion.'.! !

XpfTestCase subclass: #XpfTaskTest
	instanceVariableNames: 'testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Models'!

!XpfTaskTest methodsFor: 'running' stamp: 'mt 2/14/2009 15:18'!
setUp
	testProject := XpfProject new title: 'testProject'; yourself.! !

!XpfTaskTest methodsFor: 'running' stamp: 'mt 2/14/2009 15:18'!
tearDown
	testProject := nil.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 14:37'!
testAttributes
	| t |
	t := XpfTask new.
	self
		checkAccessor: #title on: t with: 'SVN einrichten';
		checkAccessor: #explanation on: t with: 'SVN auf dem Server installieren und Benutzer einrichten.';
		checkAccessor: #timeEstimated on: t with: 10;
		checkAccessor: #timeActual on: t with: 12;
		checkAccessor: #userStories on: t with: (Set with: XpfUserStory new with: XpfUserStory new). ! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:53'!
testHasUserStories
	| userStory task storyCount |
	storyCount := testProject userStories size.
	task := XpfTask new.
	userStory := XpfUserStory new.
	
	self should: task userStories size = 0.
	
	testProject attachTask: task.
	task attachUserStory: userStory.
	self
		should: task userStories size = 1;
		should: testProject userStories size = (storyCount + 1);
		should: (userStory tasks includes: task).
		
	task detachUserStory: userStory.
	self
		should: task userStories size = 0;
		should: testProject userStories size = (storyCount + 1).
		
	task delete.
	userStory delete.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:26'!
testNewAndDelete
	| task oldCount |
	
	oldCount := testProject tasks size.
	
	task := testProject attachTask: (XpfTask new
			title: 'test task';
			explanation: 'this is a test task';
			yourself).
		
	self 
		should: testProject tasks size = (oldCount + 1);
		should: (testProject tasks anySatisfy: [ :each | each title = 'test task' ]).
	
	task delete.
	
	self should: testProject tasks size = oldCount.! !

!XpfTestCase class methodsFor: 'testing' stamp: 'topa 2/13/2009 14:04'!
isAbstract
 	^self name = #XpfTestCase! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 10:53'!
checkAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject"
	
	aTargetObject perform: aSelector asMutator with: anObject.
	self
		should: (aTargetObject perform: aSelector) == anObject
		! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 14:03'!
denyAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject
	 that dont behave like plain accessors.
	"
	self
		shouldnt: (aTargetObject perform: aSelector) == anObject
		! !

XpfTestCase subclass: #XpfUserStoryTest
	instanceVariableNames: 'testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Models'!

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 2/14/2009 14:48'!
setUp
	testProject := XpfProject new title: 'testProject'; yourself.! !

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 2/14/2009 14:48'!
tearDown
	testProject := nil.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 14:44'!
testAttributes
	| us |
	us := XpfUserStory new.
	self
		checkAccessor: #title on: us with: 'US + Tasks verwalten';
		checkAccessor: #explanation on: us with: 'Dinge tun und Sachen machen';
		checkAccessor: #priority on: us with: 5;
		checkAccessor: #timeEstimated on: us  with: 10;
		checkAccessor: #timeActual on: us  with: 12;
		checkAccessor: #tasks on: us  with: (Set with: XpfTask new with: XpfTask new). 
		
! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:40'!
testHasTasks
	
	| userStory taskCount task|
	userStory := testProject attachUserStory: XpfUserStory new.
	taskCount := testProject tasks size.
	
	self should: userStory tasks size = 0.
	task := userStory attachTask: XpfTask new.
	
	self 
		should: userStory tasks size = 1 description: 'Task count for user story is invalid.';
		should: testProject tasks size = (taskCount + 1);
		should: 	(task userStories includes: userStory).
	userStory detachTask: task.
	
	self 
		should: userStory tasks size = 0;
		should: testProject tasks size = (taskCount + 1).
	
	userStory delete.
	task delete.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:07'!
testNewAndDelete
	| userStory oldCount |
	oldCount := testProject userStories size.
	userStory := testProject attachUserStory: (XpfUserStory new
			title: 'User Authentication';
			explanation: 'Users should register and login to the system.';
			priority: 3;
			timeEstimated: 10;
			yourself).
	self
		should: testProject userStories size = (oldCount + 1);
		should: (testProject userStories anySatisfy: [ :each | each title = 'User Authentication' ]).
	testProject detachUserStory: userStory.
	self should: testProject userStories size = oldCount! !

XpfTestCase subclass: #XpfUserTest
	instanceVariableNames: 'testUser users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Models'!

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 2/16/2009 17:17'!
login
	^ 'test.user'! !

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 2/16/2009 17:17'!
password
	^ 'TEST'! !

!XpfUserTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:23'!
setUp
	users := XpfUser users.
	XpfUser users: Set new.
	testUser := XpfUser new login: self class login; password: self class password.! !

!XpfUserTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:23'!
tearDown
	XpfUser users: users.
	testUser := nil.! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/13/2009 15:12'!
testAttributes
	| user |
	user := XpfUser new.
	self
		checkAccessor: #login on: user with: 'marcel.taeumel';
		checkAccessor: #firstName on: user with: 'Marcel';
		checkAccessor: #lastName on: user with: 'Taeumel';
		checkAccessor: #email on: user with: 'marcel.taeumel@student.hpi.uni-potsdam.de'.! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/14/2009 17:42'!
testHasProjects
	
	| projectCount project globalProjectCount |
	
	projectCount := testUser projects size.
	globalProjectCount := XpfProject all size.
	project := testUser attachProject:
		(XpfProject new
			title: 'xpforums';
			yourself).
		
	self 
		should: XpfProject all size = (globalProjectCount + 1);
		should: testUser projects size = (projectCount + 1);
		should: (XpfProject all includes: project);
		should: (testUser projects includes: project).
	testUser detachProject: project.
	
	self 
		should: XpfProject all size = (globalProjectCount + 1);
		should: testUser projects size = projectCount;
		should: (XpfProject all includes: project);
		shouldnt: (testUser projects includes: project).! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/14/2009 16:09'!
testNewAndDelete
	| user oldCount |
	
	self shouldnt: (XpfUser all anySatisfy: [ :each | each login = 'stefanc.richter' ]).
	
	oldCount := XpfUser all size.
	
	user := XpfUser addUser: (XpfUser new
			login: 'stefanc.richter';
			firstName: 'Stefan';
			lastName: 'Richter';
			email: 'stefanc.richter@student.hpi.uni-potsdam.de';
			yourself).
		
	self 
		should: XpfUser all size = (oldCount + 1);
		should: (XpfUser all anySatisfy: [ :each | each login = 'stefanc.richter' ]).
	
	XpfUser deleteUser: user.
	
	self should: XpfUser all size = oldCount.! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:18'!
testPasswordHashing

	self 
		shouldnt: (testUser respondsTo: #password); "Write only"
		should: (testUser authenticateBy: self class password);
		shouldnt: (testUser authenticateBy: self class password , 'NOT').! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:19'!
testUserAuthenticationFail

	XpfUser addUser: testUser.
	self
		should: (XpfUser authenticate: self class login by: self class password, 'NOT') isNil;
		should: (XpfUser authenticate: self class login, 'NOT' by: self class password) isNil;
		should: (XpfUser authenticate: self class login, 'NOT' by: self class password, 'NOT') isNil.
	
	XpfUser deleteUser: testUser.! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:20'!
testUserAuthenticationSuccess

	XpfUser addUser: testUser.
	
	self should: testUser = (XpfUser authenticate: self class login  by: self class password).
	
	XpfUser deleteUser: testUser.! !

!Text methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 17:42'!
removeAttributeOfKind: attClass from: start to: stop 
	"Removes an attribute kind over the interval start to stop."
	runs :=  runs copyReplaceFrom: start to: stop
			with: ((runs copyFrom: start to: stop)
				mapValues:
				[:attributes | attributes reject: [:each | each isKindOf: attClass]])! !

OBTextMorphEditorWithShout subclass: #XpfEditor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker'!

!XpfEditor class methodsFor: 'as yet unclassified' stamp: 'mt 2/5/2009 17:36'!
initializeCmdKeyShortcuts
	super initializeCmdKeyShortcuts.
	CmdActions
		at: ($q asInteger + 1) put: #markAsGood:;
		at: ($r asInteger + 1) put: #markAsBad:;
		at: ($t asInteger + 1) put: #markAsUnclear:;
		at: ($w asInteger + 1) put: #removeMarkup:.
	
! !

!XpfEditor methodsFor: 'as yet unclassified' stamp: 'mt 1/23/2009 14:43'!
markAsBad: aCharacterStream
	paragraph setBackgroundForSelectionWith: Color red.
	self userHasEdited.
	^ true

	
! !

!XpfEditor methodsFor: 'as yet unclassified' stamp: 'mt 1/23/2009 14:44'!
markAsGood: aCharacterStream
	paragraph setBackgroundForSelectionWith: Color green.
	self userHasEdited.
	^ true
	
! !

!XpfEditor methodsFor: 'as yet unclassified' stamp: 'mfp 2/3/2009 16:17'!
markAsUnclear: aCharacterStream
	paragraph setBackgroundForSelectionWith: Color lightGray.
	self userHasEdited.
	^ true
	
! !

!XpfEditor methodsFor: 'as yet unclassified' stamp: 'mt 2/5/2009 17:36'!
removeMarkup: aCharacterStream
	paragraph removeBackgroundForSelection.
	self userHasEdited.
	^ true

	
! !

Object subclass: #XpfEntity
	instanceVariableNames: 'id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

!XpfEntity commentStamp: 'mt 2/12/2009 12:20' prior: 0!
I am the abstract superclass of all entities in the system. These entities could be user stories, tasks, developers, themes, ...!

!XpfEntity methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:41'!
id
	^ id! !

!XpfEntity methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:41'!
id: anObject
	id := anObject! !

XpfEntity subclass: #XpfProject
	instanceVariableNames: 'title userStories tasks developers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

XpfProject class
	instanceVariableNames: 'projects lastId'!

XpfProject class
	instanceVariableNames: 'projects lastId'!

!XpfProject class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:34'!
addProject: aProject
	self projects add: aProject.
	aProject id: self incrementId.
	^ aProject! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:37'!
all
	^ self projects! !

!XpfProject class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:37'!
deleteProject: aProject
	self projects remove: aProject.! !

!XpfProject class methodsFor: 'private' stamp: 'topa 2/16/2009 10:36'!
incrementId
	self pvtLastId: self pvtLastId + 1.
	^ self pvtLastId! !

!XpfProject class methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:37'!
initialize
	super initialize.
	self 
		projects: Set new;
		pvtLastId: 0.! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:37'!
projects
	^ projects! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:38'!
projects: aCollection
	projects := aCollection.! !

!XpfProject class methodsFor: 'private' stamp: 'topa 2/16/2009 10:35'!
pvtLastId
	^ lastId! !

!XpfProject class methodsFor: 'private' stamp: 'topa 2/16/2009 10:35'!
pvtLastId: anInteger
	lastId := anInteger.! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:38'!
attachDeveloper: aUser

	self developers add: aUser ifPresent: [^ aUser].
	XpfUser addUser: aUser.
	aUser attachProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
attachTask: aTask
	aTask project: self.
	^ self tasks add: aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
attachUserStory: aUserStory
	aUserStory project: self.
	^ self userStories add: aUserStory
! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
detachDeveloper: aUser
	
	self developers remove: aUser ifAbsent: [^ aUser].
	aUser detachProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:43'!
detachTask: aTask

	self tasks remove: aTask ifAbsent: [^ aTask].
	aTask project: nil.
	^ aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:44'!
detachUserStory: aUserStory

	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory project: nil.
	^ aUserStory! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
developers
	^ developers! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
developers: anObject
	developers := anObject! !

!XpfProject methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:44'!
initialize
	super initialize.
	self
		userStories: Set new;
		tasks: Set new;
		developers: Set new.
	! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
tasks
	^ tasks! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
tasks: anObject
	tasks := anObject! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:09'!
title
	^ title! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:09'!
title: anObject
	title := anObject! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
userStories
	^ userStories! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
userStories: anObject
	userStories := anObject! !

XpfEntity subclass: #XpfTask
	instanceVariableNames: 'title explanation userStories timeEstimated timeActual project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

!XpfTask commentStamp: 'mt 2/12/2009 12:22' prior: 0!
I am a task in tems of Extreme Programming.!

!XpfTask methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:33'!
attachUserStory: aUserStory

	self userStories add: aUserStory ifPresent: [^ aUserStory].	
	self project attachUserStory: aUserStory.
	aUserStory attachTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'deleting' stamp: 'mt 2/14/2009 15:52'!
delete
	"Deletes this task. Detaches all connections first."
	
	self userStories do: [:us | us detachTask: self].
	self project detachTask: self.! !

!XpfTask methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:19'!
detachUserStory: aUserStory

	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory detachTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
explanation
	^ explanation! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
explanation: anObject
	explanation := anObject! !

!XpfTask methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:33'!
initialize
	super initialize.
	self userStories: Set new.! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 15:42'!
project
	^ project! !

!XpfTask methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 15:42'!
project: anObject
	project := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual
	^ timeActual! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual: anObject
	timeActual := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated
	^ timeEstimated! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated: anObject
	timeEstimated := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
title
	^ title! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
title: anObject
	title := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
userStories
	^ userStories! !

!XpfTask methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 15:10'!
userStories: anObject
	userStories := anObject! !

XpfEntity subclass: #XpfUser
	instanceVariableNames: 'login firstName lastName email projects password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

XpfUser class
	instanceVariableNames: 'users'!

!XpfUser commentStamp: 'mt 2/12/2009 12:24' prior: 0!
I am a system or application user. This could be an administrator, webmaster, developer or something like that.!

XpfUser class
	instanceVariableNames: 'users'!

!XpfUser class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:21'!
addUser: aUser
	^ self users add: aUser
! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
all
	^ self users! !

!XpfUser class methodsFor: 'authentication' stamp: 'topa 2/16/2009 17:07'!
authenticate: aLogin by: aPassword
	
	^ self all 
		detect: [ :aUser| (aUser login = aLogin) and: [aUser authenticateBy: aPassword]]
		ifNone: [nil]! !

!XpfUser class methodsFor: 'registration' stamp: 'topa 2/16/2009 17:10'!
deleteUser: aUser
	^ self users remove: aUser ifAbsent: [^ aUser]
! !

!XpfUser class methodsFor: 'authentication' stamp: 'topa 2/16/2009 16:52'!
hash: aString
	^ SecureHashAlgorithm new hashMessage: aString! !

!XpfUser class methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:08'!
initialize
	super initialize.
	self users: Set new.! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:32'!
users 
	^ users! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:08'!
users: aCollection
	users := aCollection.! !

!XpfUser methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:30'!
attachProject: aProject

	self projects add:  aProject ifPresent: [^ aProject].
	XpfProject addProject: aProject.
	aProject attachDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'authentication' stamp: 'topa 2/16/2009 16:53'!
authenticateBy: aString
	^ self pvtPassword = (self class hash: aString)! !

!XpfUser methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:30'!
detachProject: aProject
	
	self projects remove: aProject ifAbsent: [^aProject].	
	aProject detachDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
email
	^ email! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
email: anObject
	email := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
firstName
	^ firstName! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
firstName: anObject
	firstName := anObject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:13'!
initialize
	super initialize.
	self projects: Set new.! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
lastName
	^ lastName! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
lastName: anObject
	lastName := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:31'!
login
	^ login! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
login: anObject
	login := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 16:53'!
password: aString
	password := self class hash: aString! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:31'!
projects
	^ projects! !

!XpfUser methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 17:21'!
projects: anObject
	projects := anObject! !

!XpfUser methodsFor: 'accessing-private' stamp: 'topa 2/16/2009 16:46'!
pvtPassword
	^ password! !

XpfEntity subclass: #XpfUserStory
	instanceVariableNames: 'title priority timeEstimated tasks timeActual explanation project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

!XpfUserStory commentStamp: 'topa 2/12/2009 14:06' prior: 0!
I am a user story in terms of Extreme Programming!

!XpfUserStory methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:29'!
attachTask: aTask

	self tasks add: aTask ifPresent: [^ aTask].
	self project attachTask: aTask.
	aTask attachUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'deleting' stamp: 'topa 2/16/2009 10:06'!
delete
	"Deletes this user story from the system. Detaches all connections first.
	 TODO
	"! !

!XpfUserStory methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:20'!
detachTask: aTask

	self tasks remove: aTask ifAbsent: [^aTask].
	aTask detachUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
explanation
	^ explanation! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
explanation: anObject
	explanation := anObject! !

!XpfUserStory methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:06'!
initialize
	super initialize.
	self tasks: Set new.! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
priority
	^ priority! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
priority: anObject
	priority := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
project
	^ project! !

!XpfUserStory methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 15:42'!
project: anObject
	project := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
tasks
	^ tasks! !

!XpfUserStory methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 14:36'!
tasks: anObject
	tasks := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
timeActual
	^ timeActual! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual: anObject
	timeActual := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
timeEstimated
	^ timeEstimated! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated: anObject
	timeEstimated := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
title
	^ title! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
title: anObject
	title := anObject! !

SHTextStylerST80 subclass: #XpfTextStyler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker'!

!XpfTextStyler methodsFor: 'private' stamp: 'mt 1/26/2009 14:55'!
privateFormat: aText
	^super privateFormat: aText.! !

!XpfTextStyler methodsFor: 'private' stamp: 'topa 2/13/2009 14:09'!
privateStyle: aText
	"First, backup current style information about background color in text runs. Then let Shout work. Then restore background color information for text runs."

	| backupRuns |
	backupRuns := aText runs.

	super privateStyle: aText.
	
	backupRuns withStartStopAndValueDo: [:start :stop :attrs | |a|
		a := attrs detect: [:attr | attr isKindOf: XpfTextBackgroundColor] ifNone: [nil].
		a ifNotNil: [aText addAttribute: a from: start to: stop].
	]! !

!XpfTextStyler methodsFor: 'as yet unclassified' stamp: 'topa 2/13/2009 14:09'!
unstyledTextFrom: aText

	| backupRuns result |
	backupRuns := aText runs.

	result := super unstyledTextFrom: aText.
	
	backupRuns withStartStopAndValueDo: [:start :stop :attrs | |a|
		a := attrs detect: [:attr | attr isKindOf: XpfTextBackgroundColor] ifNone: [nil].
		a ifNotNil: [result addAttribute: a from: start to: stop].
	].

	^result.! !

!OBCodeBrowser methodsFor: '*xpf-codemarker-commands' stamp: 'topa 2/13/2009 13:41'!
cmdMarkAsBad
	^ XpfMarkBadCommand! !

!OBCodeBrowser methodsFor: '*xpf-codemarker-commands' stamp: 'topa 2/13/2009 13:41'!
cmdMarkAsGood
	^ XpfMarkGoodCommand! !

!OBCodeBrowser methodsFor: '*xpf-codemarker-commands' stamp: 'topa 2/13/2009 13:41'!
cmdMarkAsUnclear
	^ XpfMarkUnclearCommand! !

!OBCodeBrowser methodsFor: '*xpf-codemarker-commands' stamp: 'topa 2/13/2009 13:43'!
cmdRemoveMarkup
	^ XpfRemoveMarkupCommand! !

!Collection methodsFor: '*xpf-adding' stamp: 'test 2/16/2009 10:28'!
add: anObject ifPresent: aBlock
	"Add an object if it is absent. Else run the block"
	
	(self includes: anObject) 
		ifFalse: [^ self add: anObject]
		ifTrue: [^ aBlock value]
! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:08'!
markBadIcon
	^ Icons
			at: #'markBad'
			ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self markBadIconContents readStream) ].! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:06'!
markBadIconContents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABGdBTUEAAK/INwWK6QAAABl0
RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAACxSURBVDjL7dItC8JQAIXh491H
WbDvD1pEDIIKm1zDxqKi0WIULAZFYc1msF3ErEZlMC9Mhxx/gTAR28KpDxx4QRK/DCXwAbDg
0oLMTShtQF0F5AlwvwHkqy+Zxxs+lwsmvs8DKrIw8DCh8njNLOxRtxrU4yF3MFRhIBFQ2XxG
3W7yXq8xjULGsIsDFwF58zzq0YBpFPDc6XIKp/iFI4S7h5BbWGoFW03gyABVtyzxT8Ab8Xze
i+tkcykAAAAASUVORK5CYII='! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:08'!
markGoodIcon
	^ Icons
			at: #'markGood'
			ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self markGoodIconContents readStream) ].! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:06'!
markGoodIconContents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABGdBTUEAAK/INwWK6QAAABl0
RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAAC5SURBVDjLY/j//z8DJZhh1ADs
BjjsspIC4gb77ZZX7TdbXLVda9Zgs8xEihQDGmZfm/7/0KOD/3ff3/V/6plJ/y3mGjYQbYD9
NsurBx4e+D/10tT/nWc6/i+5sui/+RS9q0QbYLfB/OrWO1v+d5/p+t96qvn/3Auz/pt0aRNv
gPVyk4appyf+X3xl4f/ZF2b+n3Co579+mSrxXrCcZyhlMV2/wbRP56pRq+ZV3SLlBq1EOanR
lEgjAwAXIuIDq5qm/AAAAABJRU5ErkJggg=='! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:08'!
markUnknownIcon
	^ Icons
			at: #'markUnknown'
			ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self markUnknownIconContents readStream) ].! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:07'!
markUnknownIconContents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAABGdBTUEAAK/INwWK6QAAABl0
RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAABlSURBVCjPY/jPgB8yDC4FilKK
DfJXZa6KNwhKYVfQkPW/63/b/+T/XA1YFchd7fqf/j/2f+N/5qtYFUhe7fif9D/sf91/BuwK
hBoS/jcBpcP/M2C3gluKrYHhKhA2MEgN2pDEDgEb0f5zlvXgVgAAAABJRU5ErkJggg=='! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:08'!
removeMarkupIcon
	^ Icons
			at: #'removeMarkup'
			ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self removeMarkupIconContents readStream) ].! !

!MenuIcons class methodsFor: '*xpf-codemarker' stamp: 'mt 2/5/2009 18:07'!
removeMarkupIconContents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAABGdBTUEAAK/INwWK6QAAABl0
RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAABbSURBVCjPzdAxDoAgEERRzsFp
95JbGI2ASA2SCOX3Ahtr8tuXTDIO959bCxRfpOitWS5vA+lMJg9JbKCTTmMQ1QS3ThqVQbBB
lsbgpXLYE8lHCXrqLptf9km7Dzv+FwGTaznIAAAAAElFTkSuQmCC'! !

!OBPluggableTextMorphWithShout class methodsFor: '*xpf-codemarker' stamp: 'mt 1/26/2009 14:54'!
on: anObject text: getTextSel accept: setTextSel readSelection: getSelectionSel menu: getMenuSel
	|styler answer stylerClass |
	answer := self new.
	stylerClass := answer stylerClass.
	styler := stylerClass
		ifNotNil:[
			stylerClass new
				view: answer;
				yourself].
	^ answer
		styler: styler;
		on: anObject
		text: getTextSel
		accept: setTextSel
		readSelection: getSelectionSel
		menu: getMenuSel! !

!OBPluggableTextMorphWithShout methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:48'!
stylerClass
	^XpfTextStyler! !

!OBPluggableTextMorphWithShout methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:48'!
textMorphClass
	"Answer the class used to create the receiver's textMorph"
	^XpfTextMorph! !

OBTextMorphWithShout subclass: #XpfTextMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker'!

!XpfTextMorph methodsFor: 'private' stamp: 'topa 2/13/2009 14:09'!
editorClass
	"Answer the class used to create the receiver's editor"
	
	^XpfEditor! !

!RunArray class methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:50'!
scanFrom: strm
	"Read the style section of a fileOut or sources file.  nextChunk has already been done.  We need to return a RunArray of TextAttributes of various kinds.  These are written by the implementors of writeScanOn:"
	| rr vv aa this |
	(strm peekFor: $( ) ifFalse: [^ nil].
	rr := OrderedCollection new.
	[strm skipSeparators.
	 strm peekFor: $)] whileFalse: 
		[rr add: (Number readFrom: strm)].
	vv := OrderedCollection new.	"Value array"
	aa := OrderedCollection new.	"Attributes list"
	[(this := strm next) == nil] whileFalse: [
		this == $, ifTrue: [vv add: aa asArray.  aa := OrderedCollection new].
		this == $a ifTrue: [aa add: 
			(TextAlignment new alignment: (Integer readFrom: strm))].
		this == $f ifTrue: [aa add: 
			(TextFontChange new fontNumber: (Integer readFrom: strm))].
		this == $F ifTrue: [aa add: (TextFontReference toFont: 
			(StrikeFont familyName: (strm upTo: $#) size: (Integer readFrom: strm)))].
		this == $b ifTrue: [aa add: (TextEmphasis bold)].
		this == $i ifTrue: [aa add: (TextEmphasis italic)].
		this == $u ifTrue: [aa add: (TextEmphasis underlined)].
		this == $= ifTrue: [aa add: (TextEmphasis struckOut)].
		this == $n ifTrue: [aa add: (TextEmphasis normal)].
		this == $- ifTrue: [aa add: (TextKern kern: -1)].
		this == $+ ifTrue: [aa add: (TextKern kern: 1)].
		this == $c ifTrue: [aa add: (TextColor scanFrom: strm)]. "color"
		this == $h ifTrue: [aa add: (XpfTextBackgroundColor scanFrom: strm)]. "background color - CodeMarker"
		this == $L ifTrue: [aa add: (TextLink scanFrom: strm)].	"L not look like 1"
		this == $R ifTrue: [aa add: (TextURL scanFrom: strm)].
				"R capitalized so it can follow a number"
		this == $q ifTrue: [aa add: (TextSqkPageLink scanFrom: strm)].
		this == $p ifTrue: [aa add: (TextSqkProjectLink scanFrom: strm)].
		this == $P ifTrue: [aa add: (TextPrintIt scanFrom: strm)].
		this == $d ifTrue: [aa add: (TextDoIt scanFrom: strm)].
		"space, cr do nothing"
		].
	aa size > 0 ifTrue: [vv add: aa asArray].
	^ self runs: rr asArray values: vv asArray
"
RunArray scanFrom: (ReadStream on: '(14 50 312)f1,f1b,f1LInteger +;i')
"! !

!MCStWriter methodsFor: '*xpf' stamp: 'SR 1/29/2009 18:45'!
writeMethodPreamble: definition
	stream
		cr;
		nextPut: $!!;
		nextPutAll: definition fullClassName;
		nextPutAll: ' methodsFor: ';
		nextPutAll: definition category asString printString;
		nextPutAll: ' stamp: ';
		nextPutAll: definition timeStamp asString printString;
		nextPutAll: '!!';
		cr! !

!MCStWriter methodsFor: '*xpf' stamp: 'cs 2/5/2009 17:03'!
writeMethodSource: definition
	stream nextChunkPutWithStyle: definition sourceCode.! !

!MCMethodDefinition class methodsFor: '*xpf' stamp: 'SR 1/27/2009 16:38'!
clearCachedDefinitions
	Definitions := nil.
	Instances := nil.! !

!MCMethodDefinition class methodsFor: '*xpf' stamp: 'cs 2/5/2009 16:55'!
forMethodReference: aMethodReference
	| definition |
	definition := self cachedDefinitions at: aMethodReference compiledMethod ifAbsent: [].
	(definition isNil
		or: [definition selector ~= aMethodReference methodSymbol]
		or: [definition className ~= aMethodReference classSymbol]
		or: [definition classIsMeta ~= aMethodReference classIsMeta]
		or: [definition category ~= aMethodReference category])
			ifTrue: [definition := self 
						className: aMethodReference classSymbol
						classIsMeta: aMethodReference classIsMeta
						selector: aMethodReference methodSymbol
						category: aMethodReference category
						timeStamp: aMethodReference timeStamp
						source: aMethodReference sourceCode.
					self cachedDefinitions at: aMethodReference compiledMethod put: definition].
	^ definition! !

!MCMethodDefinition methodsFor: '*xpf' stamp: 'cs 2/5/2009 16:57'!
initializeWithClassName: classString
classIsMeta: metaBoolean
selector: selectorString
category: catString
timeStamp: timeString
source: sourceString
	className := classString asSymbol.
	selector := selectorString asSymbol.
	category := catString asSymbol.
	timeStamp := timeString.
	classIsMeta := metaBoolean.
	source := sourceString.! !

!MCMethodDefinition methodsFor: '*xpf' stamp: 'cs 2/5/2009 16:59'!
source
	^ source asString withSqueakLineEndings! !

!MCMethodDefinition methodsFor: '*xpf' stamp: 'cs 2/5/2009 16:57'!
sourceCode
	^source asText! !

!MultiNewParagraph methodsFor: '*xpf-codemarker' stamp: 'mt 1/22/2009 16:27'!
displayOn: aCanvas using: displayScanner at: somePosition 
	"Send all visible lines to the displayScanner for display"
	| visibleRectangle offset leftInRun line |
	visibleRectangle := aCanvas clipRect.
	offset := somePosition - positionWhenComposed.
	leftInRun := 0.
	(self lineIndexForPoint: visibleRectangle topLeft) 
		to: (self lineIndexForPoint: visibleRectangle bottomRight)
		do: 
			[ :i | 
			line := lines at: i.
			self
				drawBackgroundOn: aCanvas
					at: line;
				displaySelectionInLine: line
					on: aCanvas.
			line first <= line last ifTrue: 
				[ leftInRun := displayScanner 
					displayLine: line
					offset: offset
					leftInRun: leftInRun ] ]! !

!MultiNewParagraph methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:46'!
drawBackgroundOn: aCanvas at: line 
	| cb1 cb2 textLine bgAttr |
	textLine := self text 
		copyFrom: line first
		to: line last.
	textLine runs withStartStopAndValueDo: 
		[ :start :stop :attributes | 
		bgAttr := attributes 
			detect: [ :each | each isMemberOf: XpfTextBackgroundColor ]
			ifNone: [  ].
		bgAttr ifNotNil: 
			[ cb1 := self characterBlockForIndex: start + (line first - 1).
			cb2 := self characterBlockForIndex: stop + (line first - 1).
			aCanvas 
				fillRectangle: (cb1 left @ line top corner: cb2 right @ line bottom)
				color: bgAttr color ] ]! !

!MultiNewParagraph methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:46'!
removeBackgroundForSelection
	selectionStart stringIndex == selectionStop ifTrue: [^nil].
	self text removeAttributeOfKind: XpfTextBackgroundColor from: selectionStart stringIndex to: selectionStop stringIndex - 1! !

!MultiNewParagraph methodsFor: '*xpf-codemarker' stamp: 'topa 2/13/2009 13:46'!
setBackgroundForSelectionWith: aColor
	selectionStart stringIndex == selectionStop ifTrue: [^nil].
	self text addAttribute: (XpfTextBackgroundColor new color: aColor; yourself) from: selectionStart stringIndex to: selectionStop stringIndex - 1! !

OBCommand subclass: #XpfCodeMarkCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker-Commands'!

!XpfCodeMarkCommand class methodsFor: 'testing' stamp: 'cs 1/27/2009 17:30'!
takesText
	^ true! !

!XpfCodeMarkCommand methodsFor: 'as yet unclassified' stamp: 'mfp 2/3/2009 16:13'!
execute
	"'inspired' by ORCmdPrettyPrint>>execute"
	| panel morph editor |
	
	panel := requestor browser panels 
		detect: [ :each | each isKindOf: OBDefinitionPanel ]
		ifNone: [ ^ self ].
	morph := OBPluggableTextMorph allSubInstances
		detect: [ :each | each model == panel ]
		ifNone: [ ^ self ].
	editor := morph textMorph editor.
	self mark: target in: editor.
	morph hasUnacceptedEdits: true! !

!XpfCodeMarkCommand methodsFor: 'accessing' stamp: 'cs 1/27/2009 17:31'!
group
	^ #general! !

!XpfCodeMarkCommand methodsFor: 'testing' stamp: 'cs 1/27/2009 17:31'!
isActive
	^ target isKindOf: OBTextSelection! !

!XpfCodeMarkCommand methodsFor: 'as yet unclassified' stamp: 'mfp 2/3/2009 16:14'!
mark: aTarget in: anEditor
	^ self subclassResponsibility! !

XpfCodeMarkCommand subclass: #XpfMarkBadCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker-Commands'!

!XpfMarkBadCommand methodsFor: 'accessing' stamp: 'mt 2/5/2009 18:09'!
icon
	^#markBadIcon! !

!XpfMarkBadCommand methodsFor: 'accessing' stamp: 'mfp 2/3/2009 16:12'!
keystroke
	^ $B! !

!XpfMarkBadCommand methodsFor: 'accessing' stamp: 'mfp 2/3/2009 16:11'!
label
	^ 'mark bad'! !

!XpfMarkBadCommand methodsFor: 'editor-bridge' stamp: 'mfp 2/3/2009 16:15'!
mark: aTarget in: anEditor
	anEditor markAsBad: aTarget.! !

XpfCodeMarkCommand subclass: #XpfMarkGoodCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker-Commands'!

!XpfMarkGoodCommand methodsFor: 'accessing' stamp: 'mt 2/5/2009 18:11'!
icon
	^#markGoodIcon.! !

!XpfMarkGoodCommand methodsFor: 'accessing' stamp: 'mfp 2/3/2009 16:20'!
keystroke
	^ $G! !

!XpfMarkGoodCommand methodsFor: 'accessing' stamp: 'mfp 2/3/2009 16:20'!
label
	^ 'mark good'! !

!XpfMarkGoodCommand methodsFor: 'editor-bridge' stamp: 'mfp 2/3/2009 16:20'!
mark: aTarget in: anEditor
	anEditor markAsGood: aTarget.! !

XpfCodeMarkCommand subclass: #XpfMarkUnclearCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker-Commands'!

!XpfMarkUnclearCommand methodsFor: 'accessing' stamp: 'mt 2/5/2009 18:11'!
icon
	^#markUnknownIcon.! !

!XpfMarkUnclearCommand methodsFor: 'accessing' stamp: 'mfp 2/3/2009 16:24'!
keystroke
	^ $U! !

!XpfMarkUnclearCommand methodsFor: 'accessing' stamp: 'mfp 2/3/2009 16:24'!
label
	^ 'mark unclear'! !

!XpfMarkUnclearCommand methodsFor: 'editor-bridge' stamp: 'mfp 2/3/2009 16:25'!
mark: aTarget in: anEditor
	anEditor markAsUnclear: aTarget.! !

XpfCodeMarkCommand subclass: #XpfRemoveMarkupCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker-Commands'!

!XpfRemoveMarkupCommand methodsFor: 'as yet unclassified' stamp: 'mt 2/5/2009 18:11'!
icon
	^#removeMarkupIcon.! !

!XpfRemoveMarkupCommand methodsFor: 'as yet unclassified' stamp: 'mt 2/5/2009 17:46'!
label
	^'remove markup'! !

!XpfRemoveMarkupCommand methodsFor: 'as yet unclassified' stamp: 'mt 2/5/2009 17:44'!
mark: aTarget in: anEditor
	anEditor removeMarkup: aTarget.! !

TextAttribute subclass: #XpfTextBackgroundColor
	instanceVariableNames: 'color'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-CodeMarker'!

!XpfTextBackgroundColor class methodsFor: 'instance creation' stamp: 'mt 1/26/2009 09:31'!
color: aColor
	^ self new color: aColor! !

!XpfTextBackgroundColor class methodsFor: 'instance creation' stamp: 'mt 1/26/2009 09:42'!
scanFrom: strm
	"read a color in the funny format used by Text styles on files. c125000255 or cblue;"

	| r g b |
	strm peek isDigit
		ifTrue:
			[r := (strm next: 3) asNumber.
			g := (strm next: 3) asNumber.
			b := (strm next: 3) asNumber.
			^ self color: (Color r: r g: g b: b range: 255)].
	"A name of a color"
	^ self color: (Color perform: (strm upTo: $;) asSymbol)! !

!XpfTextBackgroundColor methodsFor: 'comparing' stamp: 'mt 1/22/2009 11:23'!
= other 
	^ (other class == self class) 
		and: [other color = color]! !

!XpfTextBackgroundColor methodsFor: 'html' stamp: 'mt 1/22/2009 11:24'!
closeHtmlOn: aStream 
	"put on the given stream the tag to close the html  
	representation of the receiver"
	aStream nextPutAll: '</span>'! !

!XpfTextBackgroundColor methodsFor: 'accessing' stamp: 'mt 1/22/2009 11:22'!
color
	^ color! !

!XpfTextBackgroundColor methodsFor: 'accessing' stamp: 'mt 1/22/2009 17:51'!
color: aColor
	color := aColor copy alpha: 0.4.! !

!XpfTextBackgroundColor methodsFor: 'scanning' stamp: 'mt 1/22/2009 11:26'!
dominates: other
	^ other class == self class! !

!XpfTextBackgroundColor methodsFor: 'comparing' stamp: 'mt 1/22/2009 11:23'!
hash
	^ color hash! !

!XpfTextBackgroundColor methodsFor: 'html' stamp: 'mt 1/22/2009 11:25'!
openHtmlOn: aStream 
	"put on the given stream the tag to open the html  
	representation of the receiver"
	aStream nextPutAll: '<span style="background-color: #' , color printHtmlString , '">'! !

!XpfTextBackgroundColor methodsFor: 'printing' stamp: 'mt 1/22/2009 11:25'!
printOn: aStream
	super printOn: aStream.
	aStream nextPutAll: ' code: '; print: color! !

!XpfTextBackgroundColor methodsFor: 'scanning' stamp: 'mt 1/22/2009 11:27'!
writeScanOn: strm
	"Two formats.  c125000255 or cblue;"

	| nn str |
	strm nextPut: $h. "h ... highlight"
	(nn := color name) ifNotNil: [
		(self class respondsTo: nn) ifTrue: [
			^ strm nextPutAll: nn; nextPut: $;]].
	(Array with: color red with: color green with: color blue) do: [:float |
		str := '000', (float * 255) asInteger printString.
		strm nextPutAll: (str copyFrom: str size-2 to: str size)]! !
XpfProject initialize!
XpfUser initialize!
